summaryrefslogtreecommitdiffstats
path: root/csit
diff options
context:
space:
mode:
authorhalil.cakal <halil.cakal@est.tech>2022-11-14 15:46:34 +0100
committerhalil.cakal <halil.cakal@est.tech>2022-11-18 09:33:04 +0000
commitc72b0875d2e8f4e9ce7868b846a466aa62467175 (patch)
tree06011b1593bc9fb5d77942527815fb7392aa3dad /csit
parent47970acb0720d20059fe40084e987be31107449e (diff)
Fix DOC config files
Fix breaking API documentation generationi and replace ROBOT_VENV with ROBOT3_VENV Issue-ID: DOC-798 Signed-off-by: marineMD <marine.de.dorlodot@intl.att.com> Change-Id: Ic9b887a8f6c96ed332cde9997efb3471e7e2e35f Signed-off-by: halil.cakal <halil.cakal@est.tech>
Diffstat (limited to 'csit')
-rwxr-xr-xcsit/prepare-csit.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/csit/prepare-csit.sh b/csit/prepare-csit.sh
index 163698d6..3e5fa143 100755
--- a/csit/prepare-csit.sh
+++ b/csit/prepare-csit.sh
@@ -1,6 +1,6 @@
#!/bin/bash -x
#
-# Copyright 2019-2021 © Samsung Electronics Co., Ltd.
+# Copyright 2019-2022 © Samsung Electronics Co., Ltd.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -26,15 +26,15 @@ fi
TESTPLANDIR=${WORKSPACE}/${TESTPLAN}
# Assume that if ROBOT_VENV is set and virtualenv with system site packages can be activated,
# ci-management/jjb/integration/include-raw-integration-install-robotframework.sh has already
# been executed
if [ -f ${WORKSPACE}/env.properties ]; then
source ${WORKSPACE}/env.properties
fi
-if [ -f ${ROBOT_VENV}/bin/activate ]; then
- source ${ROBOT_VENV}/bin/activate
+if [ -f ${ROBOT3_VENV}/bin/activate ]; then
+ source ${ROBOT3_VENV}/bin/activate
else
rm -rf /tmp/ci-management
rm -f ${WORKSPACE}/env.properties
@@ -44,8 +44,8 @@ else
fi
# install eteutils
-mkdir -p ${ROBOT_VENV}/src/onap
-rm -rf ${ROBOT_VENV}/src/onap/testsuite
+mkdir -p ${ROBOT3_VENV}/src/onap
+rm -rf ${ROBOT3_VENV}/src/onap/testsuite
pip install --upgrade --extra-index-url="https://nexus3.onap.org/repository/PyPi.staging/simple" 'robotframework-onap==0.5.1.*' --pre
pip freeze
@@ -26,15 +26,15 @@ fi
TESTPLANDIR=${WORKSPACE}/${TESTPLAN}
-# Assume that if ROBOT_VENV is set and virtualenv with system site packages can be activated,
+# Assume that if ROBOT3_VENV is set and virtualenv with system site packages can be activated,
# ci-management/jjb/integration/include-raw-integration-install-robotframework.sh has already
# been executed